@@ -7,18 +7,24 @@ def findCosineDistance(source_representation, test_representation):
     return 1 - (a / (np.sqrt(b) * np.sqrt(c)))
 
 def findEuclideanDistance(source_representation, test_representation):
+    if type(source_representation) == list:
+        source_representation = np.array(source_representation)
+
+    if type(test_representation) == list:
+        test_representation = np.array(test_representation)
+
     euclidean_distance = source_representation - test_representation
     euclidean_distance = np.sum(np.multiply(euclidean_distance, euclidean_distance))
     euclidean_distance = np.sqrt(euclidean_distance)
     return euclidean_distance
 
 def l2_normalize(x):
-    return x / np.sqrt(np.sum(np.multiply(x, x)))	
+    return x / np.sqrt(np.sum(np.multiply(x, x)))
 
 def findThreshold(model_name, distance_metric):
-	
+
 	base_threshold = {'cosine': 0.40, 'euclidean': 0.55, 'euclidean_l2': 0.75}
-	
+
 	thresholds = {
 		'VGG-Face': {'cosine': 0.40, 'euclidean': 0.55, 'euclidean_l2': 0.75},
 		'OpenFace': {'cosine': 0.10, 'euclidean': 0.55, 'euclidean_l2': 0.55},
@@ -30,5 +36,5 @@ def findThreshold(model_name, distance_metric):
 		}
 
 	threshold = thresholds.get(model_name, base_threshold).get(distance_metric, 0.4)
-	
-	return threshold
\ No newline at end of file
+
+	return threshold
